Crate libmcl_sys

source ·

Structs

Constants

Functions

  • @brief Execute a specified task
  • @brief Uninitialize MCL.
  • @brief Gets information about the specified device
  • @brief Gets the number of available devices
  • @brief Free MCL handle and associated task @pre Must be called after task has finished
  • @brief Initialize MCL
  • @brief Complete the task without executing (i.e. trigger dependencies)
  • @brief Create an empty MCL task
  • @brief Creates a new task and initializes it with the specified kernel
  • @brief Set up an argument associated with a task
  • @brief Initialize a task to run the specified kernel
  • @brief Check the status of the handle
  • @brief Create a transfer task. A transfer task executes no computation, but can be used to put or remove buffers from devices (i.e. if a an address needs to be invalidated because it might be reused later in the program for a different buffer)
  • @brief Executes a transfer. Asychronously moves data
  • @brief Frees data associated with the transfer handle
  • @brief Sets up an argument for a transfer handle. Same as mcl_task_set_arg but for a transfer.
  • @brief Checks the status of a transfer
  • @brief Waits for transfers to complete
  • @brief Block until the task associated with handle has finished
  • @brief Wait for all pending mcl tasks

Type Definitions