mcl_register_buffer

Function mcl_register_buffer 

pub unsafe extern "C" fn mcl_register_buffer(
    buffer: *mut c_void,
    size: size_t,
    flags: u64,
) -> c_int
@brief Register a buffer for future use with MCL resident memory @ingroup Args

Use of this method allows exploitation of subbuffers using offsets. When MCL sees this buffer in a task It will know that it is a reference to this section of memory, and it will use the same device allocation, using only a portion of a large device buffer if necessary

@param buffer Pointer to the data @param size Size of the allocation @param flags Argument flags, must include MCL_ARG_BUFFER | MCL_ARG_RESIDENT @return int status of call, < 0 on failure