Crate libmcl_sys
source · [−]Structs
Constants
Functions
@brief Gets information about the specified device
@brief Gets the number of available devices
@brief Free MCL handle and associated task @pre Must be called after task has finished
@brief Create an empty MCL task
@brief Creates a new task and initializes it with the specified kernel
@brief Set up an argument associated with a task
@brief Initialize a task to run the specified kernel
@brief Create a transfer task. A transfer task executes no computation, but can be used to put or remove buffers from devices (i.e. if a an address needs to be invalidated because it might be reused later in the program for a different buffer)
@brief Executes a transfer. Asychronously moves data
@brief Frees data associated with the transfer handle
@brief Sets up an argument for a transfer handle. Same as mcl_task_set_arg but for a transfer.
@brief Checks the status of a transfer
@brief Waits for transfers to complete
@brief Wait for all pending mcl tasks