pub unsafe extern "C" fn mcl_invalidate_buffer(
buffer: *mut c_void,
) -> c_intExpand description
@brief Invalidates device allocations @ingroup Args
This method will delete on device allocations associated with the buffer, but keep the reference in MCL resident data for future use. @param buffer Pointer to the data (previously used) @return int