pub unsafe extern "C" fn mcl_transfer_create(
    nargs: u64,
    ncopies: u64,
    flags: u64
) -> *mut mcl_transfer
@brief Create a transfer task. A transfer task executes no computation, but can be used to put or remove buffers from devices (i.e. if a an address needs to be invalidated because it might be reused later in the program for a different buffer)

@param nargs Number of arguments to transfer @param ncopies Hint to the number of copies to make. @param flags Flgas @return mcl_transfer* The allocated transfer handle