pub unsafe extern "C" fn mcl_unregister_buffer(
buffer: *mut c_void,
) -> c_intExpand description
@brief Unregisters a buffer from MCL Resident memory. @ingroup Args
This method will remove any device allocation associated with the memory pointer. This could be resident data created during the running of a task, or with a buffer passed to mcl_register_buffer. This method is not necessary (but still valid) if MCL_ARG_DONE was passed to a previous kernel call
@param buffer Pointer to the data @return int Status of call (if memory was able to be freed).